/* News Style */

/*Do not delete!*/
/* %1 - newsTextFontFamily */
/* %2 - newsTextFontSize */
/* %3 - newsTitleFontFamily */
/* %4 - newsTitleFontSize */
/* %5 - 0 */
/* %6 - color separator */
/* %7 - news background */
/* %8 - title background */
/* %9 - link color */
/* %10 - title color */
/* %11 - date color */
/* %12 - author color */
/* %13 - text color */
/* %14 - text-align */
/* %15 - direction: ltr or rtl */
/* %16 - "date" text-align */

body {
  overflow: auto;
  margin: 0;
  font-family: %1;
  font-size: %2pt;
  background: %7;
}

td {
  font-family: %1;
  font-size: %2pt;
}

img:not(.quiterss-img) {
  display: block;
  max-width: 100%;
  height: auto;
}

div {
  display: block;
}

a {
  color: %9;
  text-decoration: none;
}

.read-action {
  float: %14;
  width: 16px;
  margin-%16: 5px;
}

.feed-icon, .star-action, .labels-menu, .share-menu, .open-browser {
  float: %14;
  margin-%16: 10px;
}

.delete-action {
  float: %16;
}

.title {
  color: %10;
  font-family: %3;
  font-size: %4pt;
  text-align: %14;
  direction: %15;
  vertical-align: top;
}
.title a.unread {
  font-weight: bold;
}

.title a.read {
  font-weight: normal;
}

.date {
  color: %11;
  text-align: %16;
  vertical-align: top;
  white-space: nowrap;
}

.author {
  color: %12;
  text-align: %14;
  direction: %15;
  vertical-align: top;
}

a.enclosure {
  color: %12;
}
.enclosureImg {
  max-width: 100%;
}

.labels td {
  color: %12;
  text-align: %14;
  direction: %15;
  vertical-align: top;
}

.titleTable {
  background: %8;
  border-top: 0px solid %6;
  border-bottom: 1px solid %6;
  text-align: %14;
  width: 100%;
  padding: 5px;
  position: -webkit-sticky;
  top: 0;
}

.newsTable {
  border-top: 0px solid %6;
  border-bottom: 0px solid %6;
  text-align: %14;
  direction: %15;
  width: 100%;
  padding: 5px;
  color: %13;
}

/* Prevent content 'div's from changing table width */
.newsTable td div[style] {
    width: 100% !important;
}
